#include <stdio.h>
#include <stdlib.h>
#include <string.h>

const long MAX_LINES_COUNT = 304; //304
const long DIRS_COUNT = 4; //4
const long TRIANGLE_DIRS_COUNT = 2; //2;
const long HYPOTENUSE_DIRS_COUNT = 2; //2

const long perpendicularDir[TRIANGLE_DIRS_COUNT] = {2, 3};
const long hypotenuseDir[TRIANGLE_DIRS_COUNT][HYPOTENUSE_DIRS_COUNT] =
{ {1, 3}, {0, 2} };

template<class Type>
inline Type Det2(const Type &a, const Type &b, const Type &c, const Type &d)
{
	return a * d - b * c;
}

template<class Type>
inline Type Sign(const Type &value)
{
	if(value < 0)return -1;
	if(value > 0)return 1;
	return 0;
}

inline void SolveLinear2
(
	long a1, long b1, long c1,
	long a2, long b2, long c2,
	long *x, long *y
)
{
	static long detX, detY, det;
	det  = Det2( a1,  b1,  a2,  b2);
	detX = Det2(-c1,  b1, -c2,  b2);
	detY = Det2( a1, -c1,  a2, -c2);
	*x = detX / det;
	*y = detY / det;
}


struct tVector2D
{
	long x, y;

	tVector2D(void) : x(0), y(0) {};
	tVector2D(long initX, long initY) : x(initX), y(initY) {};

	void Read(void)
	{
		scanf("%ld %ld", &x, &y);
	}

	void operator *= (long mult)
	{
		x *= mult;
		y *= mult;
	}

	long operator * (const tVector2D &vector) const
	{
		return x * vector.x + y * vector.y;
	}

	tVector2D operator - (const tVector2D &vector) const
	{
		return tVector2D(x - vector.x, y - vector.y);
	}

	long GetDir(void) const
	{
		if(y == 0)return 0;
		if(x == y)return 1;
		if(x == 0)return 2;
		return 3;
	}

	int operator == (const tVector2D &vector) const
	{
		return (x == vector.x && y == vector.y);
	}
};

const tVector2D gNormals[DIRS_COUNT] =
{
	tVector2D(0, -1),
	tVector2D(1, -1),
	tVector2D(1, 0),
	tVector2D(1, 1)
};

struct tLine
{
	tVector2D normal;
	long parameter, dir;

	tLine(void) : parameter(0) {}

	tLine(long x1, long y1, long x2, long y2)
	{
		static tVector2D begin, end;
		begin = tVector2D(x1, y1);
		end = tVector2D(x2, y2);
		Init(begin, end);
	}

	void Init(const tVector2D &begin, const tVector2D &end)
	{
		dir = (begin - end).GetDir();
		normal = gNormals[dir];
		parameter = - (normal * begin);
	}

	void Read(void)
	{
		static tVector2D begin, end;
		begin.Read(); end.Read();
		begin *= 2; end *= 2;
		Init(begin, end);
	}

	int Compare(const tLine &line)const
	{
		return Sign(parameter - line.parameter);
	}

	tVector2D Intersect(const tLine &line)const
	{
		static tVector2D result;
		SolveLinear2
		(
			normal.x, normal.y, parameter,
			line.normal.x, line.normal.y, line.parameter,
			&result.x, &result.y
		);
		return result;
	}

	long CalcDeviationSign(const tVector2D &vector)
	{
		return Sign(normal * vector + parameter);
	}
};

struct tField
{
	static tVector2D fieldSize;
	static int OnField(const tVector2D &point)
	{
		if(point.x < 0 || point.y < 0)return 0;
		if(point.x > fieldSize.x || point.y > fieldSize.y)return 0;
		return 1;
	}
};

tVector2D tField::fieldSize;
long gcTriangles;
tLine lines[MAX_LINES_COUNT];
long iLinesByDirs[DIRS_COUNT][MAX_LINES_COUNT];
long cLinesByDirs[DIRS_COUNT];

int CmpLines(const void *piLine1, const void *piLine2)
{
	return lines[*(long*)piLine1].Compare(lines[*(long*)piLine2]);
}

long FindBorder(long dir, const tVector2D *points, long cPoints, long borderDir)
{
	static long left, right, center, iPoint, deviationSign;
	left = 0;
	right = cLinesByDirs[dir] - 1;
	while(left != right)
	{
		if(borderDir == -1)
			center = (left + right + 1) >> 1;
		else
			center = (left + right) >> 1;
		for(iPoint = 0; iPoint < cPoints; ++iPoint)
		{
			deviationSign = lines[iLinesByDirs[dir][center]].CalcDeviationSign(points[iPoint]);
			if(deviationSign && deviationSign != borderDir)break;
		}
		if(borderDir == -1)
			if(iPoint == cPoints)left = center;
			else right = center - 1 ;
		else
			if(iPoint == cPoints)right = center;
			else left = center + 1;
	}

    return left;
}

void FindBorders(long dir, const tVector2D *points, long cPoints, long *iLeft, long *iRight)
{
	*iLeft = FindBorder(dir, points, cPoints, 1);
	*iRight = FindBorder(dir, points, cPoints, -1);
}

void CheckTriangle(const tVector2D triangle[3])
{
	if
	(
		triangle[0] == triangle[1] ||
		triangle[1] == triangle[2] ||
		triangle[2] == triangle[0]
	)return;

	if(! tField::OnField(triangle[0]))return;
	if(! tField::OnField(triangle[1]))return;
	if(! tField::OnField(triangle[2]))return;

	static long iLeft, iRight, dir;
	for(dir = 0; dir < DIRS_COUNT; ++dir)
	{
		FindBorders(dir, triangle, 3, &iLeft, &iRight);
		if(labs(iLeft - iRight) > 1)return;
	}

	++gcTriangles;
}

int main(void)
{
	freopen("inlay.in", "r", stdin);
	freopen("inlay.out", "w", stdout);

	tField::fieldSize.Read();
	tField::fieldSize *= 2;

	long cLines, iLine;
	scanf("%ld", &cLines);

	for(iLine = 0; iLine < cLines; ++iLine)
		lines[iLine].Read();

	lines[cLines++] = tLine(0, 0, tField::fieldSize.x, 0);
	lines[cLines++] = tLine(tField::fieldSize.x, 0, tField::fieldSize.x, tField::fieldSize.y);
	lines[cLines++] = tLine(tField::fieldSize.x, tField::fieldSize.y, 0, tField::fieldSize.y);
	lines[cLines++] = tLine(0, tField::fieldSize.y, 0, 0);
	lines[cLines++] = tLine(tField::fieldSize.x + 2, 0, tField::fieldSize.x, -2);
	lines[cLines++] = tLine(-2, tField::fieldSize.y, 0, tField::fieldSize.y + 2);
	lines[cLines++] = tLine(-2, 0, 0, -2);
	lines[cLines++] = tLine(tField::fieldSize.x, tField::fieldSize.y + 2, tField::fieldSize.x + 2, tField::fieldSize.y);

	memset(cLinesByDirs, 0, sizeof(cLinesByDirs));

	long iDir, dir1, dir2, hypDir, iHypDir;

	for(iLine = 0; iLine < cLines; ++iLine)
	{
		iDir = lines[iLine].dir;
		iLinesByDirs[iDir][cLinesByDirs[iDir]++] = iLine;
	}

	for(iDir = 0; iDir < DIRS_COUNT; ++iDir)
		qsort
		(
			iLinesByDirs[iDir],
			cLinesByDirs[iDir],
			sizeof(iLinesByDirs[iDir][0]),
			CmpLines
		);

	gcTriangles = 0;

	long iLine1, iLine2;

	for(iDir = 0; iDir < TRIANGLE_DIRS_COUNT; ++iDir)
	{
		dir1 = iDir;
		dir2 = perpendicularDir[iDir];
		for(iLine1 = 0; iLine1 < cLinesByDirs[dir1]; ++iLine1)
			for(iLine2 = 0; iLine2 < cLinesByDirs[dir2]; ++iLine2)
			{
				static tVector2D triangle[3];
				triangle[0] = lines[iLinesByDirs[dir1][iLine1]].Intersect
					(lines[iLinesByDirs[dir2][iLine2]]);
				if(! tField::OnField(triangle[0]))continue;
				static long iLeft, iRight;
				for(iHypDir = 0; iHypDir < HYPOTENUSE_DIRS_COUNT; iHypDir ++)
				{
					hypDir = hypotenuseDir[iDir][iHypDir];
					FindBorders(hypDir, &triangle[0], 1, &iLeft, &iRight);
					if(iLeft == iRight) --iLeft, ++iRight;
					if(iLeft < 0)iLeft = 0;
					if(iRight >= cLinesByDirs[hypDir])
						iRight = cLinesByDirs[hypDir] - 1;
					triangle[1] = lines[iLinesByDirs[dir1][iLine1]].Intersect
						(lines[iLinesByDirs[hypDir][iLeft]]);
					triangle[2] = lines[iLinesByDirs[dir2][iLine2]].Intersect
						(lines[iLinesByDirs[hypDir][iLeft]]);
					CheckTriangle(triangle);
					if(iLeft != iRight)
					{
						triangle[1] = lines[iLinesByDirs[dir1][iLine1]].Intersect
							(lines[iLinesByDirs[hypDir][iRight]]);
						triangle[2] = lines[iLinesByDirs[dir2][iLine2]].Intersect
							(lines[iLinesByDirs[hypDir][iRight]]);
						CheckTriangle(triangle);
					}
				}
			}
	}

	printf("%ld", gcTriangles);

	fclose(stdout);
	fclose(stdin);

	return 0;
}